# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .annotation import *
from .dashboard import *
from .dashboard_permission import *
from .dashboard_permission_item import *
from .dashboard_public import *
from .data_source import *
from .data_source_config import *
from .folder import *
from .folder_permission import *
from .folder_permission_item import *
from .get_dashboard import *
from .get_dashboards import *
from .get_data_source import *
from .get_folder import *
from .get_folders import *
from .get_library_panel import *
from .get_library_panels import *
from .get_organization import *
from .get_organization_preferences import *
from .get_organization_user import *
from .get_service_account import *
from .get_team import *
from .get_user import *
from .get_users import *
from .library_panel import *
from .organization import *
from .organization_preferences import *
from .playlist import *
from .service_account import *
from .service_account_permission import *
from .service_account_permission_item import *
from .service_account_token import *
from .sso_settings import *
from .team import *
from .user import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'AppsDashboardMetadata',
    'AppsDashboardOptions',
    'AppsDashboardSpec',
    'AppsPlaylistV0Alpha1Metadata',
    'AppsPlaylistV0Alpha1Options',
    'AppsPlaylistV0Alpha1Spec',
    'AppsPlaylistV0Alpha1SpecItem',
]

@pulumi.output_type
class AppsDashboardMetadata(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "folderUid":
            suggest = "folder_uid"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AppsDashboardMetadata. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AppsDashboardMetadata.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AppsDashboardMetadata.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 uid: builtins.str,
                 folder_uid: Optional[builtins.str] = None,
                 url: Optional[builtins.str] = None,
                 uuid: Optional[builtins.str] = None,
                 version: Optional[builtins.str] = None):
        """
        :param builtins.str uid: The unique identifier of the resource.
        :param builtins.str folder_uid: The UID of the folder to save the resource in.
        :param builtins.str url: The full URL of the resource.
        :param builtins.str uuid: The globally unique identifier of a resource, used by the API for tracking.
        :param builtins.str version: The version of the resource.
        """
        pulumi.set(__self__, "uid", uid)
        if folder_uid is not None:
            pulumi.set(__self__, "folder_uid", folder_uid)
        if url is not None:
            pulumi.set(__self__, "url", url)
        if uuid is not None:
            pulumi.set(__self__, "uuid", uuid)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def uid(self) -> builtins.str:
        """
        The unique identifier of the resource.
        """
        return pulumi.get(self, "uid")

    @property
    @pulumi.getter(name="folderUid")
    def folder_uid(self) -> Optional[builtins.str]:
        """
        The UID of the folder to save the resource in.
        """
        return pulumi.get(self, "folder_uid")

    @property
    @pulumi.getter
    def url(self) -> Optional[builtins.str]:
        """
        The full URL of the resource.
        """
        return pulumi.get(self, "url")

    @property
    @pulumi.getter
    def uuid(self) -> Optional[builtins.str]:
        """
        The globally unique identifier of a resource, used by the API for tracking.
        """
        return pulumi.get(self, "uuid")

    @property
    @pulumi.getter
    def version(self) -> Optional[builtins.str]:
        """
        The version of the resource.
        """
        return pulumi.get(self, "version")


@pulumi.output_type
class AppsDashboardOptions(dict):
    def __init__(__self__, *,
                 overwrite: Optional[builtins.bool] = None):
        """
        :param builtins.bool overwrite: Set to true if you want to overwrite existing resource with newer version, same resource title in folder or same resource uid.
        """
        if overwrite is not None:
            pulumi.set(__self__, "overwrite", overwrite)

    @property
    @pulumi.getter
    def overwrite(self) -> Optional[builtins.bool]:
        """
        Set to true if you want to overwrite existing resource with newer version, same resource title in folder or same resource uid.
        """
        return pulumi.get(self, "overwrite")


@pulumi.output_type
class AppsDashboardSpec(dict):
    def __init__(__self__, *,
                 json: builtins.str,
                 tags: Optional[Sequence[builtins.str]] = None,
                 title: Optional[builtins.str] = None):
        """
        :param builtins.str json: The JSON representation of the dashboard spec.
        :param Sequence[builtins.str] tags: The tags of the dashboard. If not set, the tags will be derived from the JSON spec.
        :param builtins.str title: The title of the dashboard. If not set, the title will be derived from the JSON spec.
        """
        pulumi.set(__self__, "json", json)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if title is not None:
            pulumi.set(__self__, "title", title)

    @property
    @pulumi.getter
    def json(self) -> builtins.str:
        """
        The JSON representation of the dashboard spec.
        """
        return pulumi.get(self, "json")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Sequence[builtins.str]]:
        """
        The tags of the dashboard. If not set, the tags will be derived from the JSON spec.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def title(self) -> Optional[builtins.str]:
        """
        The title of the dashboard. If not set, the title will be derived from the JSON spec.
        """
        return pulumi.get(self, "title")


@pulumi.output_type
class AppsPlaylistV0Alpha1Metadata(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "folderUid":
            suggest = "folder_uid"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AppsPlaylistV0Alpha1Metadata. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AppsPlaylistV0Alpha1Metadata.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AppsPlaylistV0Alpha1Metadata.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 uid: builtins.str,
                 folder_uid: Optional[builtins.str] = None,
                 url: Optional[builtins.str] = None,
                 uuid: Optional[builtins.str] = None,
                 version: Optional[builtins.str] = None):
        """
        :param builtins.str uid: The unique identifier of the resource.
        :param builtins.str folder_uid: The UID of the folder to save the resource in.
        :param builtins.str url: The full URL of the resource.
        :param builtins.str uuid: The globally unique identifier of a resource, used by the API for tracking.
        :param builtins.str version: The version of the resource.
        """
        pulumi.set(__self__, "uid", uid)
        if folder_uid is not None:
            pulumi.set(__self__, "folder_uid", folder_uid)
        if url is not None:
            pulumi.set(__self__, "url", url)
        if uuid is not None:
            pulumi.set(__self__, "uuid", uuid)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def uid(self) -> builtins.str:
        """
        The unique identifier of the resource.
        """
        return pulumi.get(self, "uid")

    @property
    @pulumi.getter(name="folderUid")
    def folder_uid(self) -> Optional[builtins.str]:
        """
        The UID of the folder to save the resource in.
        """
        return pulumi.get(self, "folder_uid")

    @property
    @pulumi.getter
    def url(self) -> Optional[builtins.str]:
        """
        The full URL of the resource.
        """
        return pulumi.get(self, "url")

    @property
    @pulumi.getter
    def uuid(self) -> Optional[builtins.str]:
        """
        The globally unique identifier of a resource, used by the API for tracking.
        """
        return pulumi.get(self, "uuid")

    @property
    @pulumi.getter
    def version(self) -> Optional[builtins.str]:
        """
        The version of the resource.
        """
        return pulumi.get(self, "version")


@pulumi.output_type
class AppsPlaylistV0Alpha1Options(dict):
    def __init__(__self__, *,
                 overwrite: Optional[builtins.bool] = None):
        """
        :param builtins.bool overwrite: Set to true if you want to overwrite existing resource with newer version, same resource title in folder or same resource uid.
        """
        if overwrite is not None:
            pulumi.set(__self__, "overwrite", overwrite)

    @property
    @pulumi.getter
    def overwrite(self) -> Optional[builtins.bool]:
        """
        Set to true if you want to overwrite existing resource with newer version, same resource title in folder or same resource uid.
        """
        return pulumi.get(self, "overwrite")


@pulumi.output_type
class AppsPlaylistV0Alpha1Spec(dict):
    def __init__(__self__, *,
                 items: Sequence['outputs.AppsPlaylistV0Alpha1SpecItem'],
                 title: builtins.str,
                 interval: Optional[builtins.str] = None):
        """
        :param Sequence['AppsPlaylistV0Alpha1SpecItemArgs'] items: The items of the playlist.
        :param builtins.str title: The title of the playlist.
        :param builtins.str interval: The interval of the playlist.
        """
        pulumi.set(__self__, "items", items)
        pulumi.set(__self__, "title", title)
        if interval is not None:
            pulumi.set(__self__, "interval", interval)

    @property
    @pulumi.getter
    def items(self) -> Sequence['outputs.AppsPlaylistV0Alpha1SpecItem']:
        """
        The items of the playlist.
        """
        return pulumi.get(self, "items")

    @property
    @pulumi.getter
    def title(self) -> builtins.str:
        """
        The title of the playlist.
        """
        return pulumi.get(self, "title")

    @property
    @pulumi.getter
    def interval(self) -> Optional[builtins.str]:
        """
        The interval of the playlist.
        """
        return pulumi.get(self, "interval")


@pulumi.output_type
class AppsPlaylistV0Alpha1SpecItem(dict):
    def __init__(__self__, *,
                 type: builtins.str,
                 value: builtins.str):
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        return pulumi.get(self, "value")





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['CollectorArgs', 'Collector']

@pulumi.input_type
class CollectorArgs:
    def __init__(__self__, *,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 remote_attributes: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a Collector resource.
        :param pulumi.Input[builtins.bool] enabled: Whether remote configuration for the collector is enabled or not. If the collector is disabled, it will receive empty configurations from the Fleet Management service
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] remote_attributes: Remote attributes for the collector
        """
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if remote_attributes is not None:
            pulumi.set(__self__, "remote_attributes", remote_attributes)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether remote configuration for the collector is enabled or not. If the collector is disabled, it will receive empty configurations from the Fleet Management service
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="remoteAttributes")
    def remote_attributes(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Remote attributes for the collector
        """
        return pulumi.get(self, "remote_attributes")

    @remote_attributes.setter
    def remote_attributes(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "remote_attributes", value)


@pulumi.input_type
class _CollectorState:
    def __init__(__self__, *,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 remote_attributes: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering Collector resources.
        :param pulumi.Input[builtins.bool] enabled: Whether remote configuration for the collector is enabled or not. If the collector is disabled, it will receive empty configurations from the Fleet Management service
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] remote_attributes: Remote attributes for the collector
        """
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if remote_attributes is not None:
            pulumi.set(__self__, "remote_attributes", remote_attributes)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether remote configuration for the collector is enabled or not. If the collector is disabled, it will receive empty configurations from the Fleet Management service
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="remoteAttributes")
    def remote_attributes(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Remote attributes for the collector
        """
        return pulumi.get(self, "remote_attributes")

    @remote_attributes.setter
    def remote_attributes(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "remote_attributes", value)


@pulumi.type_token("grafana:fleetManagement/collector:Collector")
class Collector(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 remote_attributes: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        Manages Grafana Fleet Management collectors.

        * [Official documentation](https://grafana.com/docs/grafana-cloud/send-data/fleet-management/)
        * [API documentation](https://grafana.com/docs/grafana-cloud/send-data/fleet-management/api-reference/collector-api/)

        Required access policy scopes:

        * fleet-management:read
        * fleet-management:write

        ## Import

        ```sh
        $ pulumi import grafana:fleetManagement/collector:Collector name "{{ id }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] enabled: Whether remote configuration for the collector is enabled or not. If the collector is disabled, it will receive empty configurations from the Fleet Management service
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] remote_attributes: Remote attributes for the collector
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[CollectorArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages Grafana Fleet Management collectors.

        * [Official documentation](https://grafana.com/docs/grafana-cloud/send-data/fleet-management/)
        * [API documentation](https://grafana.com/docs/grafana-cloud/send-data/fleet-management/api-reference/collector-api/)

        Required access policy scopes:

        * fleet-management:read
        * fleet-management:write

        ## Import

        ```sh
        $ pulumi import grafana:fleetManagement/collector:Collector name "{{ id }}"
        ```

        :param str resource_name: The name of the resource.
        :param CollectorArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CollectorArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 remote_attributes: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CollectorArgs.__new__(CollectorArgs)

            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["remote_attributes"] = remote_attributes
        super(Collector, __self__).__init__(
            'grafana:fleetManagement/collector:Collector',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            enabled: Optional[pulumi.Input[builtins.bool]] = None,
            remote_attributes: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None) -> 'Collector':
        """
        Get an existing Collector resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] enabled: Whether remote configuration for the collector is enabled or not. If the collector is disabled, it will receive empty configurations from the Fleet Management service
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] remote_attributes: Remote attributes for the collector
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CollectorState.__new__(_CollectorState)

        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["remote_attributes"] = remote_attributes
        return Collector(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[builtins.bool]:
        """
        Whether remote configuration for the collector is enabled or not. If the collector is disabled, it will receive empty configurations from the Fleet Management service
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter(name="remoteAttributes")
    def remote_attributes(self) -> pulumi.Output[Mapping[str, builtins.str]]:
        """
        Remote attributes for the collector
        """
        return pulumi.get(self, "remote_attributes")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['EscalationChainArgs', 'EscalationChain']

@pulumi.input_type
class EscalationChainArgs:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 team_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a EscalationChain resource.
        :param pulumi.Input[builtins.str] name: The name of the escalation chain.
        :param pulumi.Input[builtins.str] team_id: The ID of the OnCall team (using the `on_call_get_team` datasource).
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the escalation chain.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the OnCall team (using the `on_call_get_team` datasource).
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "team_id", value)


@pulumi.input_type
class _EscalationChainState:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 team_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering EscalationChain resources.
        :param pulumi.Input[builtins.str] name: The name of the escalation chain.
        :param pulumi.Input[builtins.str] team_id: The ID of the OnCall team (using the `on_call_get_team` datasource).
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the escalation chain.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the OnCall team (using the `on_call_get_team` datasource).
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "team_id", value)


@pulumi.type_token("grafana:onCall/escalationChain:EscalationChain")
class EscalationChain(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 team_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        * [HTTP API](https://grafana.com/docs/oncall/latest/oncall-api-reference/escalation_chains/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_grafana as grafana
        import pulumiverse_grafana as grafana

        my_team = grafana.oss.get_team(name="my team")
        my_team_get_team = grafana.onCall.get_team(name=my_team.name)
        default = grafana.on_call.EscalationChain("default",
            name="default",
            team_id=my_team_get_team.id)
        ```

        ## Import

        ```sh
        $ pulumi import grafana:onCall/escalationChain:EscalationChain name "{{ id }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] name: The name of the escalation chain.
        :param pulumi.Input[builtins.str] team_id: The ID of the OnCall team (using the `on_call_get_team` datasource).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[EscalationChainArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        * [HTTP API](https://grafana.com/docs/oncall/latest/oncall-api-reference/escalation_chains/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_grafana as grafana
        import pulumiverse_grafana as grafana

        my_team = grafana.oss.get_team(name="my team")
        my_team_get_team = grafana.onCall.get_team(name=my_team.name)
        default = grafana.on_call.EscalationChain("default",
            name="default",
            team_id=my_team_get_team.id)
        ```

        ## Import

        ```sh
        $ pulumi import grafana:onCall/escalationChain:EscalationChain name "{{ id }}"
        ```

        :param str resource_name: The name of the resource.
        :param EscalationChainArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EscalationChainArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 team_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EscalationChainArgs.__new__(EscalationChainArgs)

            __props__.__dict__["name"] = name
            __props__.__dict__["team_id"] = team_id
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="grafana:index/oncallEscalationChain:OncallEscalationChain")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        super(EscalationChain, __self__).__init__(
            'grafana:onCall/escalationChain:EscalationChain',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            team_id: Optional[pulumi.Input[builtins.str]] = None) -> 'EscalationChain':
        """
        Get an existing EscalationChain resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] name: The name of the escalation chain.
        :param pulumi.Input[builtins.str] team_id: The ID of the OnCall team (using the `on_call_get_team` datasource).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EscalationChainState.__new__(_EscalationChainState)

        __props__.__dict__["name"] = name
        __props__.__dict__["team_id"] = team_id
        return EscalationChain(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the escalation chain.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="teamId")
    def team_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The ID of the OnCall team (using the `on_call_get_team` datasource).
        """
        return pulumi.get(self, "team_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ServiceAccountTokenArgs', 'ServiceAccountToken']

@pulumi.input_type
class ServiceAccountTokenArgs:
    def __init__(__self__, *,
                 service_account_id: pulumi.Input[builtins.str],
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 seconds_to_live: Optional[pulumi.Input[builtins.int]] = None):
        """
        The set of arguments for constructing a ServiceAccountToken resource.
        :param pulumi.Input[builtins.str] service_account_id: The ID of the service account to which the token belongs.
        :param pulumi.Input[builtins.str] name: The name of the service account token.
        :param pulumi.Input[builtins.int] seconds_to_live: The key expiration in seconds. It is optional. If it is a positive number an expiration date for the key is set. If it is null, zero or is omitted completely (unless `api_key_max_seconds_to_live` configuration option is set) the key will never expire.
        """
        pulumi.set(__self__, "service_account_id", service_account_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if seconds_to_live is not None:
            pulumi.set(__self__, "seconds_to_live", seconds_to_live)

    @property
    @pulumi.getter(name="serviceAccountId")
    def service_account_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the service account to which the token belongs.
        """
        return pulumi.get(self, "service_account_id")

    @service_account_id.setter
    def service_account_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_account_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the service account token.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="secondsToLive")
    def seconds_to_live(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The key expiration in seconds. It is optional. If it is a positive number an expiration date for the key is set. If it is null, zero or is omitted completely (unless `api_key_max_seconds_to_live` configuration option is set) the key will never expire.
        """
        return pulumi.get(self, "seconds_to_live")

    @seconds_to_live.setter
    def seconds_to_live(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "seconds_to_live", value)


@pulumi.input_type
class _ServiceAccountTokenState:
    def __init__(__self__, *,
                 expiration: Optional[pulumi.Input[builtins.str]] = None,
                 has_expired: Optional[pulumi.Input[builtins.bool]] = None,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 seconds_to_live: Optional[pulumi.Input[builtins.int]] = None,
                 service_account_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering ServiceAccountToken resources.
        :param pulumi.Input[builtins.str] expiration: The expiration date of the service account token.
        :param pulumi.Input[builtins.bool] has_expired: The status of the service account token.
        :param pulumi.Input[builtins.str] key: The key of the service account token.
        :param pulumi.Input[builtins.str] name: The name of the service account token.
        :param pulumi.Input[builtins.int] seconds_to_live: The key expiration in seconds. It is optional. If it is a positive number an expiration date for the key is set. If it is null, zero or is omitted completely (unless `api_key_max_seconds_to_live` configuration option is set) the key will never expire.
        :param pulumi.Input[builtins.str] service_account_id: The ID of the service account to which the token belongs.
        """
        if expiration is not None:
            pulumi.set(__self__, "expiration", expiration)
        if has_expired is not None:
            pulumi.set(__self__, "has_expired", has_expired)
        if key is not None:
            pulumi.set(__self__, "key", key)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if seconds_to_live is not None:
            pulumi.set(__self__, "seconds_to_live", seconds_to_live)
        if service_account_id is not None:
            pulumi.set(__self__, "service_account_id", service_account_id)

    @property
    @pulumi.getter
    def expiration(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The expiration date of the service account token.
        """
        return pulumi.get(self, "expiration")

    @expiration.setter
    def expiration(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "expiration", value)

    @property
    @pulumi.getter(name="hasExpired")
    def has_expired(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        The status of the service account token.
        """
        return pulumi.get(self, "has_expired")

    @has_expired.setter
    def has_expired(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "has_expired", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The key of the service account token.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the service account token.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="secondsToLive")
    def seconds_to_live(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The key expiration in seconds. It is optional. If it is a positive number an expiration date for the key is set. If it is null, zero or is omitted completely (unless `api_key_max_seconds_to_live` configuration option is set) the key will never expire.
        """
        return pulumi.get(self, "seconds_to_live")

    @seconds_to_live.setter
    def seconds_to_live(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "seconds_to_live", value)

    @property
    @pulumi.getter(name="serviceAccountId")
    def service_account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the service account to which the token belongs.
        """
        return pulumi.get(self, "service_account_id")

    @service_account_id.setter
    def service_account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_account_id", value)


@pulumi.type_token("grafana:oss/serviceAccountToken:ServiceAccountToken")
class ServiceAccountToken(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 seconds_to_live: Optional[pulumi.Input[builtins.int]] = None,
                 service_account_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        **Note:** This resource is available only with Grafana 9.1+.

        * [Official documentation](https://grafana.com/docs/grafana/latest/administration/service-accounts/)
        * [HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/serviceaccount/#service-account-api)

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        test = grafana.oss.ServiceAccount("test",
            name="test-service-account",
            role="Viewer")
        foo = grafana.oss.ServiceAccountToken("foo",
            name="key_foo",
            service_account_id=test.id)
        bar = grafana.oss.ServiceAccountToken("bar",
            name="key_bar",
            service_account_id=test.id,
            seconds_to_live=30)
        pulumi.export("serviceAccountTokenFooKeyOnly", foo.key)
        pulumi.export("serviceAccountTokenBar", bar)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] name: The name of the service account token.
        :param pulumi.Input[builtins.int] seconds_to_live: The key expiration in seconds. It is optional. If it is a positive number an expiration date for the key is set. If it is null, zero or is omitted completely (unless `api_key_max_seconds_to_live` configuration option is set) the key will never expire.
        :param pulumi.Input[builtins.str] service_account_id: The ID of the service account to which the token belongs.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ServiceAccountTokenArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        **Note:** This resource is available only with Grafana 9.1+.

        * [Official documentation](https://grafana.com/docs/grafana/latest/administration/service-accounts/)
        * [HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/serviceaccount/#service-account-api)

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        test = grafana.oss.ServiceAccount("test",
            name="test-service-account",
            role="Viewer")
        foo = grafana.oss.ServiceAccountToken("foo",
            name="key_foo",
            service_account_id=test.id)
        bar = grafana.oss.ServiceAccountToken("bar",
            name="key_bar",
            service_account_id=test.id,
            seconds_to_live=30)
        pulumi.export("serviceAccountTokenFooKeyOnly", foo.key)
        pulumi.export("serviceAccountTokenBar", bar)
        ```

        :param str resource_name: The name of the resource.
        :param ServiceAccountTokenArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ServiceAccountTokenArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 seconds_to_live: Optional[pulumi.Input[builtins.int]] = None,
                 service_account_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ServiceAccountTokenArgs.__new__(ServiceAccountTokenArgs)

            __props__.__dict__["name"] = name
            __props__.__dict__["seconds_to_live"] = seconds_to_live
            if service_account_id is None and not opts.urn:
                raise TypeError("Missing required property 'service_account_id'")
            __props__.__dict__["service_account_id"] = service_account_id
            __props__.__dict__["expiration"] = None
            __props__.__dict__["has_expired"] = None
            __props__.__dict__["key"] = None
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="grafana:index/serviceAccountToken:ServiceAccountToken")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["key"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(ServiceAccountToken, __self__).__init__(
            'grafana:oss/serviceAccountToken:ServiceAccountToken',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            expiration: Optional[pulumi.Input[builtins.str]] = None,
            has_expired: Optional[pulumi.Input[builtins.bool]] = None,
            key: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            seconds_to_live: Optional[pulumi.Input[builtins.int]] = None,
            service_account_id: Optional[pulumi.Input[builtins.str]] = None) -> 'ServiceAccountToken':
        """
        Get an existing ServiceAccountToken resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] expiration: The expiration date of the service account token.
        :param pulumi.Input[builtins.bool] has_expired: The status of the service account token.
        :param pulumi.Input[builtins.str] key: The key of the service account token.
        :param pulumi.Input[builtins.str] name: The name of the service account token.
        :param pulumi.Input[builtins.int] seconds_to_live: The key expiration in seconds. It is optional. If it is a positive number an expiration date for the key is set. If it is null, zero or is omitted completely (unless `api_key_max_seconds_to_live` configuration option is set) the key will never expire.
        :param pulumi.Input[builtins.str] service_account_id: The ID of the service account to which the token belongs.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ServiceAccountTokenState.__new__(_ServiceAccountTokenState)

        __props__.__dict__["expiration"] = expiration
        __props__.__dict__["has_expired"] = has_expired
        __props__.__dict__["key"] = key
        __props__.__dict__["name"] = name
        __props__.__dict__["seconds_to_live"] = seconds_to_live
        __props__.__dict__["service_account_id"] = service_account_id
        return ServiceAccountToken(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def expiration(self) -> pulumi.Output[builtins.str]:
        """
        The expiration date of the service account token.
        """
        return pulumi.get(self, "expiration")

    @property
    @pulumi.getter(name="hasExpired")
    def has_expired(self) -> pulumi.Output[builtins.bool]:
        """
        The status of the service account token.
        """
        return pulumi.get(self, "has_expired")

    @property
    @pulumi.getter
    def key(self) -> pulumi.Output[builtins.str]:
        """
        The key of the service account token.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the service account token.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="secondsToLive")
    def seconds_to_live(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        The key expiration in seconds. It is optional. If it is a positive number an expiration date for the key is set. If it is null, zero or is omitted completely (unless `api_key_max_seconds_to_live` configuration option is set) the key will never expire.
        """
        return pulumi.get(self, "seconds_to_live")

    @property
    @pulumi.getter(name="serviceAccountId")
    def service_account_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the service account to which the token belongs.
        """
        return pulumi.get(self, "service_account_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['UserArgs', 'User']

@pulumi.input_type
class UserArgs:
    def __init__(__self__, *,
                 email: pulumi.Input[builtins.str],
                 password: pulumi.Input[builtins.str],
                 is_admin: Optional[pulumi.Input[builtins.bool]] = None,
                 login: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a User resource.
        :param pulumi.Input[builtins.str] email: The email address of the Grafana user.
        :param pulumi.Input[builtins.str] password: The password for the Grafana user.
        :param pulumi.Input[builtins.bool] is_admin: Whether to make user an admin. Defaults to `false`.
        :param pulumi.Input[builtins.str] login: The username for the Grafana user.
        :param pulumi.Input[builtins.str] name: The display name for the Grafana user.
        """
        pulumi.set(__self__, "email", email)
        pulumi.set(__self__, "password", password)
        if is_admin is not None:
            pulumi.set(__self__, "is_admin", is_admin)
        if login is not None:
            pulumi.set(__self__, "login", login)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def email(self) -> pulumi.Input[builtins.str]:
        """
        The email address of the Grafana user.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter
    def password(self) -> pulumi.Input[builtins.str]:
        """
        The password for the Grafana user.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="isAdmin")
    def is_admin(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to make user an admin. Defaults to `false`.
        """
        return pulumi.get(self, "is_admin")

    @is_admin.setter
    def is_admin(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_admin", value)

    @property
    @pulumi.getter
    def login(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The username for the Grafana user.
        """
        return pulumi.get(self, "login")

    @login.setter
    def login(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "login", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The display name for the Grafana user.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _UserState:
    def __init__(__self__, *,
                 email: Optional[pulumi.Input[builtins.str]] = None,
                 is_admin: Optional[pulumi.Input[builtins.bool]] = None,
                 login: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 user_id: Optional[pulumi.Input[builtins.int]] = None):
        """
        Input properties used for looking up and filtering User resources.
        :param pulumi.Input[builtins.str] email: The email address of the Grafana user.
        :param pulumi.Input[builtins.bool] is_admin: Whether to make user an admin. Defaults to `false`.
        :param pulumi.Input[builtins.str] login: The username for the Grafana user.
        :param pulumi.Input[builtins.str] name: The display name for the Grafana user.
        :param pulumi.Input[builtins.str] password: The password for the Grafana user.
        :param pulumi.Input[builtins.int] user_id: The numerical ID of the Grafana user.
        """
        if email is not None:
            pulumi.set(__self__, "email", email)
        if is_admin is not None:
            pulumi.set(__self__, "is_admin", is_admin)
        if login is not None:
            pulumi.set(__self__, "login", login)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The email address of the Grafana user.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter(name="isAdmin")
    def is_admin(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to make user an admin. Defaults to `false`.
        """
        return pulumi.get(self, "is_admin")

    @is_admin.setter
    def is_admin(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_admin", value)

    @property
    @pulumi.getter
    def login(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The username for the Grafana user.
        """
        return pulumi.get(self, "login")

    @login.setter
    def login(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "login", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The display name for the Grafana user.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The password for the Grafana user.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The numerical ID of the Grafana user.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "user_id", value)


warnings.warn("""grafana.index/user.User has been deprecated in favor of grafana.oss/user.User""", DeprecationWarning)


@pulumi.type_token("grafana:index/user:User")
class User(pulumi.CustomResource):
    warnings.warn("""grafana.index/user.User has been deprecated in favor of grafana.oss/user.User""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 email: Optional[pulumi.Input[builtins.str]] = None,
                 is_admin: Optional[pulumi.Input[builtins.bool]] = None,
                 login: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        * [Official documentation](https://grafana.com/docs/grafana/latest/administration/user-management/server-user-management/)
        * [HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/user/)

        This resource represents an instance-scoped resource and uses Grafana's admin APIs.
        It does not work with API tokens or service accounts which are org-scoped.
        You must use basic auth.
        This resource is also not compatible with Grafana Cloud, as it does not allow basic auth.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        staff = grafana.oss.User("staff",
            email="staff.name@example.com",
            name="Staff Name",
            login="staff",
            password="my-password",
            is_admin=False)
        ```

        ## Import

        ```sh
        $ pulumi import grafana:index/user:User name "{{ id }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] email: The email address of the Grafana user.
        :param pulumi.Input[builtins.bool] is_admin: Whether to make user an admin. Defaults to `false`.
        :param pulumi.Input[builtins.str] login: The username for the Grafana user.
        :param pulumi.Input[builtins.str] name: The display name for the Grafana user.
        :param pulumi.Input[builtins.str] password: The password for the Grafana user.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UserArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        * [Official documentation](https://grafana.com/docs/grafana/latest/administration/user-management/server-user-management/)
        * [HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/user/)

        This resource represents an instance-scoped resource and uses Grafana's admin APIs.
        It does not work with API tokens or service accounts which are org-scoped.
        You must use basic auth.
        This resource is also not compatible with Grafana Cloud, as it does not allow basic auth.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        staff = grafana.oss.User("staff",
            email="staff.name@example.com",
            name="Staff Name",
            login="staff",
            password="my-password",
            is_admin=False)
        ```

        ## Import

        ```sh
        $ pulumi import grafana:index/user:User name "{{ id }}"
        ```

        :param str resource_name: The name of the resource.
        :param UserArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UserArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 email: Optional[pulumi.Input[builtins.str]] = None,
                 is_admin: Optional[pulumi.Input[builtins.bool]] = None,
                 login: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        pulumi.log.warn("""User is deprecated: grafana.index/user.User has been deprecated in favor of grafana.oss/user.User""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UserArgs.__new__(UserArgs)

            if email is None and not opts.urn:
                raise TypeError("Missing required property 'email'")
            __props__.__dict__["email"] = email
            __props__.__dict__["is_admin"] = is_admin
            __props__.__dict__["login"] = login
            __props__.__dict__["name"] = name
            if password is None and not opts.urn:
                raise TypeError("Missing required property 'password'")
            __props__.__dict__["password"] = None if password is None else pulumi.Output.secret(password)
            __props__.__dict__["user_id"] = None
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="grafana:index/user:User")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["password"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(User, __self__).__init__(
            'grafana:index/user:User',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            email: Optional[pulumi.Input[builtins.str]] = None,
            is_admin: Optional[pulumi.Input[builtins.bool]] = None,
            login: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            password: Optional[pulumi.Input[builtins.str]] = None,
            user_id: Optional[pulumi.Input[builtins.int]] = None) -> 'User':
        """
        Get an existing User resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] email: The email address of the Grafana user.
        :param pulumi.Input[builtins.bool] is_admin: Whether to make user an admin. Defaults to `false`.
        :param pulumi.Input[builtins.str] login: The username for the Grafana user.
        :param pulumi.Input[builtins.str] name: The display name for the Grafana user.
        :param pulumi.Input[builtins.str] password: The password for the Grafana user.
        :param pulumi.Input[builtins.int] user_id: The numerical ID of the Grafana user.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UserState.__new__(_UserState)

        __props__.__dict__["email"] = email
        __props__.__dict__["is_admin"] = is_admin
        __props__.__dict__["login"] = login
        __props__.__dict__["name"] = name
        __props__.__dict__["password"] = password
        __props__.__dict__["user_id"] = user_id
        return User(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def email(self) -> pulumi.Output[builtins.str]:
        """
        The email address of the Grafana user.
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter(name="isAdmin")
    def is_admin(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Whether to make user an admin. Defaults to `false`.
        """
        return pulumi.get(self, "is_admin")

    @property
    @pulumi.getter
    def login(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The username for the Grafana user.
        """
        return pulumi.get(self, "login")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        The display name for the Grafana user.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[builtins.str]:
        """
        The password for the Grafana user.
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[builtins.int]:
        """
        The numerical ID of the Grafana user.
        """
        return pulumi.get(self, "user_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetLoadTestsResult',
    'AwaitableGetLoadTestsResult',
    'get_load_tests',
    'get_load_tests_output',
]

@pulumi.output_type
class GetLoadTestsResult:
    """
    A collection of values returned by getLoadTests.
    """
    def __init__(__self__, id=None, load_tests=None, name=None, project_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if load_tests and not isinstance(load_tests, list):
            raise TypeError("Expected argument 'load_tests' to be a list")
        pulumi.set(__self__, "load_tests", load_tests)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The identifier of the project the load tests belong to. This is set to the same as the project_id.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="loadTests")
    def load_tests(self) -> Sequence['outputs.GetLoadTestsLoadTestResult']:
        return pulumi.get(self, "load_tests")

    @property
    @pulumi.getter
    def name(self) -> Optional[builtins.str]:
        """
        Human-friendly identifier of the load test.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> builtins.str:
        """
        The identifier of the project the load tests belong to.
        """
        return pulumi.get(self, "project_id")


class AwaitableGetLoadTestsResult(GetLoadTestsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetLoadTestsResult(
            id=self.id,
            load_tests=self.load_tests,
            name=self.name,
            project_id=self.project_id)


def get_load_tests(name: Optional[builtins.str] = None,
                   project_id: Optional[builtins.str] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetLoadTestsResult:
    """
    Retrieves all k6 load tests that belong to a project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_grafana as grafana
    import pulumiverse_grafana as grafana

    load_test_project = grafana.k6.Project("load_test_project", name="Terraform Load Test Project")
    test_load_test = grafana.k6.LoadTest("test_load_test",
        project_id=load_test_project.id,
        name="Terraform Test Load Test",
        script=\"\"\"export default function() {
      console.log('Hello from k6!');
    }
    \"\"\",
        opts = pulumi.ResourceOptions(depends_on=[load_test_project]))
    test_load_test2 = grafana.k6.LoadTest("test_load_test_2",
        project_id=load_test_project.id,
        name="Terraform Test Load Test (2)",
        script=\"\"\"export default function() {
      console.log('Hello from k6!');
    }
    \"\"\",
        opts = pulumi.ResourceOptions(depends_on=[test_load_test]))
    from_project_id = grafana.k6.get_load_tests_output(project_id=load_test_project.id)
    filter_by_name = grafana.k6.get_load_tests_output(name="Terraform Test Load Test (2)",
        project_id=load_test_project.id)
    ```


    :param builtins.str name: Human-friendly identifier of the load test.
    :param builtins.str project_id: The identifier of the project the load tests belong to.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('grafana:k6/getLoadTests:getLoadTests', __args__, opts=opts, typ=GetLoadTestsResult).value

    return AwaitableGetLoadTestsResult(
        id=pulumi.get(__ret__, 'id'),
        load_tests=pulumi.get(__ret__, 'load_tests'),
        name=pulumi.get(__ret__, 'name'),
        project_id=pulumi.get(__ret__, 'project_id'))
def get_load_tests_output(name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                          project_id: Optional[pulumi.Input[builtins.str]] = None,
                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetLoadTestsResult]:
    """
    Retrieves all k6 load tests that belong to a project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_grafana as grafana
    import pulumiverse_grafana as grafana

    load_test_project = grafana.k6.Project("load_test_project", name="Terraform Load Test Project")
    test_load_test = grafana.k6.LoadTest("test_load_test",
        project_id=load_test_project.id,
        name="Terraform Test Load Test",
        script=\"\"\"export default function() {
      console.log('Hello from k6!');
    }
    \"\"\",
        opts = pulumi.ResourceOptions(depends_on=[load_test_project]))
    test_load_test2 = grafana.k6.LoadTest("test_load_test_2",
        project_id=load_test_project.id,
        name="Terraform Test Load Test (2)",
        script=\"\"\"export default function() {
      console.log('Hello from k6!');
    }
    \"\"\",
        opts = pulumi.ResourceOptions(depends_on=[test_load_test]))
    from_project_id = grafana.k6.get_load_tests_output(project_id=load_test_project.id)
    filter_by_name = grafana.k6.get_load_tests_output(name="Terraform Test Load Test (2)",
        project_id=load_test_project.id)
    ```


    :param builtins.str name: Human-friendly identifier of the load test.
    :param builtins.str project_id: The identifier of the project the load tests belong to.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('grafana:k6/getLoadTests:getLoadTests', __args__, opts=opts, typ=GetLoadTestsResult)
    return __ret__.apply(lambda __response__: GetLoadTestsResult(
        id=pulumi.get(__response__, 'id'),
        load_tests=pulumi.get(__response__, 'load_tests'),
        name=pulumi.get(__response__, 'name'),
        project_id=pulumi.get(__response__, 'project_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['MachineLearningHolidayArgs', 'MachineLearningHoliday']

@pulumi.input_type
class MachineLearningHolidayArgs:
    def __init__(__self__, *,
                 custom_periods: Optional[pulumi.Input[Sequence[pulumi.Input['MachineLearningHolidayCustomPeriodArgs']]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ical_timezone: Optional[pulumi.Input[builtins.str]] = None,
                 ical_url: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a MachineLearningHoliday resource.
        :param pulumi.Input[Sequence[pulumi.Input['MachineLearningHolidayCustomPeriodArgs']]] custom_periods: A list of custom periods for the holiday.
        :param pulumi.Input[builtins.str] description: A description of the holiday.
        :param pulumi.Input[builtins.str] ical_timezone: The timezone to use for events in the iCal file pointed to by ical_url.
        :param pulumi.Input[builtins.str] ical_url: A URL to an iCal file containing all occurrences of the holiday.
        :param pulumi.Input[builtins.str] name: The name of the holiday.
        """
        if custom_periods is not None:
            pulumi.set(__self__, "custom_periods", custom_periods)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if ical_timezone is not None:
            pulumi.set(__self__, "ical_timezone", ical_timezone)
        if ical_url is not None:
            pulumi.set(__self__, "ical_url", ical_url)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="customPeriods")
    def custom_periods(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MachineLearningHolidayCustomPeriodArgs']]]]:
        """
        A list of custom periods for the holiday.
        """
        return pulumi.get(self, "custom_periods")

    @custom_periods.setter
    def custom_periods(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MachineLearningHolidayCustomPeriodArgs']]]]):
        pulumi.set(self, "custom_periods", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A description of the holiday.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="icalTimezone")
    def ical_timezone(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The timezone to use for events in the iCal file pointed to by ical_url.
        """
        return pulumi.get(self, "ical_timezone")

    @ical_timezone.setter
    def ical_timezone(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ical_timezone", value)

    @property
    @pulumi.getter(name="icalUrl")
    def ical_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A URL to an iCal file containing all occurrences of the holiday.
        """
        return pulumi.get(self, "ical_url")

    @ical_url.setter
    def ical_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ical_url", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the holiday.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _MachineLearningHolidayState:
    def __init__(__self__, *,
                 custom_periods: Optional[pulumi.Input[Sequence[pulumi.Input['MachineLearningHolidayCustomPeriodArgs']]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ical_timezone: Optional[pulumi.Input[builtins.str]] = None,
                 ical_url: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering MachineLearningHoliday resources.
        :param pulumi.Input[Sequence[pulumi.Input['MachineLearningHolidayCustomPeriodArgs']]] custom_periods: A list of custom periods for the holiday.
        :param pulumi.Input[builtins.str] description: A description of the holiday.
        :param pulumi.Input[builtins.str] ical_timezone: The timezone to use for events in the iCal file pointed to by ical_url.
        :param pulumi.Input[builtins.str] ical_url: A URL to an iCal file containing all occurrences of the holiday.
        :param pulumi.Input[builtins.str] name: The name of the holiday.
        """
        if custom_periods is not None:
            pulumi.set(__self__, "custom_periods", custom_periods)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if ical_timezone is not None:
            pulumi.set(__self__, "ical_timezone", ical_timezone)
        if ical_url is not None:
            pulumi.set(__self__, "ical_url", ical_url)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="customPeriods")
    def custom_periods(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MachineLearningHolidayCustomPeriodArgs']]]]:
        """
        A list of custom periods for the holiday.
        """
        return pulumi.get(self, "custom_periods")

    @custom_periods.setter
    def custom_periods(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MachineLearningHolidayCustomPeriodArgs']]]]):
        pulumi.set(self, "custom_periods", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A description of the holiday.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="icalTimezone")
    def ical_timezone(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The timezone to use for events in the iCal file pointed to by ical_url.
        """
        return pulumi.get(self, "ical_timezone")

    @ical_timezone.setter
    def ical_timezone(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ical_timezone", value)

    @property
    @pulumi.getter(name="icalUrl")
    def ical_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A URL to an iCal file containing all occurrences of the holiday.
        """
        return pulumi.get(self, "ical_url")

    @ical_url.setter
    def ical_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ical_url", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the holiday.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)


warnings.warn("""grafana.index/machinelearningholiday.MachineLearningHoliday has been deprecated in favor of grafana.machinelearning/holiday.Holiday""", DeprecationWarning)


@pulumi.type_token("grafana:index/machineLearningHoliday:MachineLearningHoliday")
class MachineLearningHoliday(pulumi.CustomResource):
    warnings.warn("""grafana.index/machinelearningholiday.MachineLearningHoliday has been deprecated in favor of grafana.machinelearning/holiday.Holiday""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 custom_periods: Optional[pulumi.Input[Sequence[pulumi.Input[Union['MachineLearningHolidayCustomPeriodArgs', 'MachineLearningHolidayCustomPeriodArgsDict']]]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ical_timezone: Optional[pulumi.Input[builtins.str]] = None,
                 ical_url: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        A holiday describes time periods where a time series is expected to behave differently to normal.

        To use a holiday in a job, use its id in the `holidays` attribute of a `machineLearning.Job`:

        ### iCal Holiday

        This holiday uses an iCal file to define the holidays.

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        ical = grafana.machine_learning.Holiday("ical",
            name="My iCal holiday",
            description="My Holiday",
            ical_url="https://calendar.google.com/calendar/ical/en.uk%23holiday%40group.v.calendar.google.com/public/basic.ics",
            ical_timezone="Europe/London")
        ```

        ### Custom Periods Holiday

        This holiday uses custom periods to define the holidays.

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        custom_periods = grafana.machine_learning.Holiday("custom_periods",
            name="My custom periods holiday",
            description="My Holiday",
            custom_periods=[
                {
                    "name": "First of January",
                    "start_time": "2023-01-01T00:00:00Z",
                    "end_time": "2023-01-02T00:00:00Z",
                },
                {
                    "name": "First of Feburary",
                    "start_time": "2023-02-01T00:00:00Z",
                    "end_time": "2023-02-02T00:00:00Z",
                },
            ])
        ```

        ## Import

        ```sh
        $ pulumi import grafana:index/machineLearningHoliday:MachineLearningHoliday name "{{ id }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['MachineLearningHolidayCustomPeriodArgs', 'MachineLearningHolidayCustomPeriodArgsDict']]]] custom_periods: A list of custom periods for the holiday.
        :param pulumi.Input[builtins.str] description: A description of the holiday.
        :param pulumi.Input[builtins.str] ical_timezone: The timezone to use for events in the iCal file pointed to by ical_url.
        :param pulumi.Input[builtins.str] ical_url: A URL to an iCal file containing all occurrences of the holiday.
        :param pulumi.Input[builtins.str] name: The name of the holiday.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[MachineLearningHolidayArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        A holiday describes time periods where a time series is expected to behave differently to normal.

        To use a holiday in a job, use its id in the `holidays` attribute of a `machineLearning.Job`:

        ### iCal Holiday

        This holiday uses an iCal file to define the holidays.

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        ical = grafana.machine_learning.Holiday("ical",
            name="My iCal holiday",
            description="My Holiday",
            ical_url="https://calendar.google.com/calendar/ical/en.uk%23holiday%40group.v.calendar.google.com/public/basic.ics",
            ical_timezone="Europe/London")
        ```

        ### Custom Periods Holiday

        This holiday uses custom periods to define the holidays.

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        custom_periods = grafana.machine_learning.Holiday("custom_periods",
            name="My custom periods holiday",
            description="My Holiday",
            custom_periods=[
                {
                    "name": "First of January",
                    "start_time": "2023-01-01T00:00:00Z",
                    "end_time": "2023-01-02T00:00:00Z",
                },
                {
                    "name": "First of Feburary",
                    "start_time": "2023-02-01T00:00:00Z",
                    "end_time": "2023-02-02T00:00:00Z",
                },
            ])
        ```

        ## Import

        ```sh
        $ pulumi import grafana:index/machineLearningHoliday:MachineLearningHoliday name "{{ id }}"
        ```

        :param str resource_name: The name of the resource.
        :param MachineLearningHolidayArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MachineLearningHolidayArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 custom_periods: Optional[pulumi.Input[Sequence[pulumi.Input[Union['MachineLearningHolidayCustomPeriodArgs', 'MachineLearningHolidayCustomPeriodArgsDict']]]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ical_timezone: Optional[pulumi.Input[builtins.str]] = None,
                 ical_url: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        pulumi.log.warn("""MachineLearningHoliday is deprecated: grafana.index/machinelearningholiday.MachineLearningHoliday has been deprecated in favor of grafana.machinelearning/holiday.Holiday""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MachineLearningHolidayArgs.__new__(MachineLearningHolidayArgs)

            __props__.__dict__["custom_periods"] = custom_periods
            __props__.__dict__["description"] = description
            __props__.__dict__["ical_timezone"] = ical_timezone
            __props__.__dict__["ical_url"] = ical_url
            __props__.__dict__["name"] = name
        super(MachineLearningHoliday, __self__).__init__(
            'grafana:index/machineLearningHoliday:MachineLearningHoliday',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            custom_periods: Optional[pulumi.Input[Sequence[pulumi.Input[Union['MachineLearningHolidayCustomPeriodArgs', 'MachineLearningHolidayCustomPeriodArgsDict']]]]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            ical_timezone: Optional[pulumi.Input[builtins.str]] = None,
            ical_url: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None) -> 'MachineLearningHoliday':
        """
        Get an existing MachineLearningHoliday resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['MachineLearningHolidayCustomPeriodArgs', 'MachineLearningHolidayCustomPeriodArgsDict']]]] custom_periods: A list of custom periods for the holiday.
        :param pulumi.Input[builtins.str] description: A description of the holiday.
        :param pulumi.Input[builtins.str] ical_timezone: The timezone to use for events in the iCal file pointed to by ical_url.
        :param pulumi.Input[builtins.str] ical_url: A URL to an iCal file containing all occurrences of the holiday.
        :param pulumi.Input[builtins.str] name: The name of the holiday.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MachineLearningHolidayState.__new__(_MachineLearningHolidayState)

        __props__.__dict__["custom_periods"] = custom_periods
        __props__.__dict__["description"] = description
        __props__.__dict__["ical_timezone"] = ical_timezone
        __props__.__dict__["ical_url"] = ical_url
        __props__.__dict__["name"] = name
        return MachineLearningHoliday(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="customPeriods")
    def custom_periods(self) -> pulumi.Output[Optional[Sequence['outputs.MachineLearningHolidayCustomPeriod']]]:
        """
        A list of custom periods for the holiday.
        """
        return pulumi.get(self, "custom_periods")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        A description of the holiday.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="icalTimezone")
    def ical_timezone(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The timezone to use for events in the iCal file pointed to by ical_url.
        """
        return pulumi.get(self, "ical_timezone")

    @property
    @pulumi.getter(name="icalUrl")
    def ical_url(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        A URL to an iCal file containing all occurrences of the holiday.
        """
        return pulumi.get(self, "ical_url")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the holiday.
        """
        return pulumi.get(self, "name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ConnectionsMetricsEndpointScrapeJobArgs', 'ConnectionsMetricsEndpointScrapeJob']

@pulumi.input_type
class ConnectionsMetricsEndpointScrapeJobArgs:
    def __init__(__self__, *,
                 authentication_method: pulumi.Input[builtins.str],
                 stack_id: pulumi.Input[builtins.str],
                 url: pulumi.Input[builtins.str],
                 authentication_basic_password: Optional[pulumi.Input[builtins.str]] = None,
                 authentication_basic_username: Optional[pulumi.Input[builtins.str]] = None,
                 authentication_bearer_token: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 scrape_interval_seconds: Optional[pulumi.Input[builtins.int]] = None):
        """
        The set of arguments for constructing a ConnectionsMetricsEndpointScrapeJob resource.
        :param pulumi.Input[builtins.str] authentication_method: Method to pass authentication credentials: basic or bearer.
        :param pulumi.Input[builtins.str] url: The url to scrape metrics from; a valid HTTPs URL is required.
        :param pulumi.Input[builtins.str] authentication_basic_password: Password for basic authentication, use if scrape job is using basic authentication method
        :param pulumi.Input[builtins.str] authentication_basic_username: Username for basic authentication, use if scrape job is using basic authentication method
        :param pulumi.Input[builtins.str] authentication_bearer_token: Bearer token used for authentication, use if scrape job is using bearer authentication method
        :param pulumi.Input[builtins.bool] enabled: Whether the metrics endpoint scrape job is enabled or not.
        :param pulumi.Input[builtins.int] scrape_interval_seconds: Frequency for scraping the metrics endpoint: 30, 60, or 120 seconds.
        """
        pulumi.set(__self__, "authentication_method", authentication_method)
        pulumi.set(__self__, "stack_id", stack_id)
        pulumi.set(__self__, "url", url)
        if authentication_basic_password is not None:
            pulumi.set(__self__, "authentication_basic_password", authentication_basic_password)
        if authentication_basic_username is not None:
            pulumi.set(__self__, "authentication_basic_username", authentication_basic_username)
        if authentication_bearer_token is not None:
            pulumi.set(__self__, "authentication_bearer_token", authentication_bearer_token)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if scrape_interval_seconds is not None:
            pulumi.set(__self__, "scrape_interval_seconds", scrape_interval_seconds)

    @property
    @pulumi.getter(name="authenticationMethod")
    def authentication_method(self) -> pulumi.Input[builtins.str]:
        """
        Method to pass authentication credentials: basic or bearer.
        """
        return pulumi.get(self, "authentication_method")

    @authentication_method.setter
    def authentication_method(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "authentication_method", value)

    @property
    @pulumi.getter(name="stackId")
    def stack_id(self) -> pulumi.Input[builtins.str]:
        return pulumi.get(self, "stack_id")

    @stack_id.setter
    def stack_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "stack_id", value)

    @property
    @pulumi.getter
    def url(self) -> pulumi.Input[builtins.str]:
        """
        The url to scrape metrics from; a valid HTTPs URL is required.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "url", value)

    @property
    @pulumi.getter(name="authenticationBasicPassword")
    def authentication_basic_password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Password for basic authentication, use if scrape job is using basic authentication method
        """
        return pulumi.get(self, "authentication_basic_password")

    @authentication_basic_password.setter
    def authentication_basic_password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "authentication_basic_password", value)

    @property
    @pulumi.getter(name="authenticationBasicUsername")
    def authentication_basic_username(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Username for basic authentication, use if scrape job is using basic authentication method
        """
        return pulumi.get(self, "authentication_basic_username")

    @authentication_basic_username.setter
    def authentication_basic_username(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "authentication_basic_username", value)

    @property
    @pulumi.getter(name="authenticationBearerToken")
    def authentication_bearer_token(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Bearer token used for authentication, use if scrape job is using bearer authentication method
        """
        return pulumi.get(self, "authentication_bearer_token")

    @authentication_bearer_token.setter
    def authentication_bearer_token(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "authentication_bearer_token", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether the metrics endpoint scrape job is enabled or not.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="scrapeIntervalSeconds")
    def scrape_interval_seconds(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Frequency for scraping the metrics endpoint: 30, 60, or 120 seconds.
        """
        return pulumi.get(self, "scrape_interval_seconds")

    @scrape_interval_seconds.setter
    def scrape_interval_seconds(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "scrape_interval_seconds", value)


@pulumi.input_type
class _ConnectionsMetricsEndpointScrapeJobState:
    def __init__(__self__, *,
                 authentication_basic_password: Optional[pulumi.Input[builtins.str]] = None,
                 authentication_basic_username: Optional[pulumi.Input[builtins.str]] = None,
                 authentication_bearer_token: Optional[pulumi.Input[builtins.str]] = None,
                 authentication_method: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 scrape_interval_seconds: Optional[pulumi.Input[builtins.int]] = None,
                 stack_id: Optional[pulumi.Input[builtins.str]] = None,
                 url: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering ConnectionsMetricsEndpointScrapeJob resources.
        :param pulumi.Input[builtins.str] authentication_basic_password: Password for basic authentication, use if scrape job is using basic authentication method
        :param pulumi.Input[builtins.str] authentication_basic_username: Username for basic authentication, use if scrape job is using basic authentication method
        :param pulumi.Input[builtins.str] authentication_bearer_token: Bearer token used for authentication, use if scrape job is using bearer authentication method
        :param pulumi.Input[builtins.str] authentication_method: Method to pass authentication credentials: basic or bearer.
        :param pulumi.Input[builtins.bool] enabled: Whether the metrics endpoint scrape job is enabled or not.
        :param pulumi.Input[builtins.int] scrape_interval_seconds: Frequency for scraping the metrics endpoint: 30, 60, or 120 seconds.
        :param pulumi.Input[builtins.str] url: The url to scrape metrics from; a valid HTTPs URL is required.
        """
        if authentication_basic_password is not None:
            pulumi.set(__self__, "authentication_basic_password", authentication_basic_password)
        if authentication_basic_username is not None:
            pulumi.set(__self__, "authentication_basic_username", authentication_basic_username)
        if authentication_bearer_token is not None:
            pulumi.set(__self__, "authentication_bearer_token", authentication_bearer_token)
        if authentication_method is not None:
            pulumi.set(__self__, "authentication_method", authentication_method)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if scrape_interval_seconds is not None:
            pulumi.set(__self__, "scrape_interval_seconds", scrape_interval_seconds)
        if stack_id is not None:
            pulumi.set(__self__, "stack_id", stack_id)
        if url is not None:
            pulumi.set(__self__, "url", url)

    @property
    @pulumi.getter(name="authenticationBasicPassword")
    def authentication_basic_password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Password for basic authentication, use if scrape job is using basic authentication method
        """
        return pulumi.get(self, "authentication_basic_password")

    @authentication_basic_password.setter
    def authentication_basic_password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "authentication_basic_password", value)

    @property
    @pulumi.getter(name="authenticationBasicUsername")
    def authentication_basic_username(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Username for basic authentication, use if scrape job is using basic authentication method
        """
        return pulumi.get(self, "authentication_basic_username")

    @authentication_basic_username.setter
    def authentication_basic_username(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "authentication_basic_username", value)

    @property
    @pulumi.getter(name="authenticationBearerToken")
    def authentication_bearer_token(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Bearer token used for authentication, use if scrape job is using bearer authentication method
        """
        return pulumi.get(self, "authentication_bearer_token")

    @authentication_bearer_token.setter
    def authentication_bearer_token(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "authentication_bearer_token", value)

    @property
    @pulumi.getter(name="authenticationMethod")
    def authentication_method(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Method to pass authentication credentials: basic or bearer.
        """
        return pulumi.get(self, "authentication_method")

    @authentication_method.setter
    def authentication_method(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "authentication_method", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether the metrics endpoint scrape job is enabled or not.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="scrapeIntervalSeconds")
    def scrape_interval_seconds(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Frequency for scraping the metrics endpoint: 30, 60, or 120 seconds.
        """
        return pulumi.get(self, "scrape_interval_seconds")

    @scrape_interval_seconds.setter
    def scrape_interval_seconds(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "scrape_interval_seconds", value)

    @property
    @pulumi.getter(name="stackId")
    def stack_id(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "stack_id")

    @stack_id.setter
    def stack_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "stack_id", value)

    @property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The url to scrape metrics from; a valid HTTPs URL is required.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "url", value)


warnings.warn("""grafana.index/connectionsmetricsendpointscrapejob.ConnectionsMetricsEndpointScrapeJob has been deprecated in favor of grafana.connections/metricsendpointscrapejob.MetricsEndpointScrapeJob""", DeprecationWarning)


@pulumi.type_token("grafana:index/connectionsMetricsEndpointScrapeJob:ConnectionsMetricsEndpointScrapeJob")
class ConnectionsMetricsEndpointScrapeJob(pulumi.CustomResource):
    warnings.warn("""grafana.index/connectionsmetricsendpointscrapejob.ConnectionsMetricsEndpointScrapeJob has been deprecated in favor of grafana.connections/metricsendpointscrapejob.MetricsEndpointScrapeJob""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 authentication_basic_password: Optional[pulumi.Input[builtins.str]] = None,
                 authentication_basic_username: Optional[pulumi.Input[builtins.str]] = None,
                 authentication_bearer_token: Optional[pulumi.Input[builtins.str]] = None,
                 authentication_method: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 scrape_interval_seconds: Optional[pulumi.Input[builtins.int]] = None,
                 stack_id: Optional[pulumi.Input[builtins.str]] = None,
                 url: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        test = grafana.connections.MetricsEndpointScrapeJob("test",
            stack_id="1",
            name="my-scrape-job",
            enabled=True,
            authentication_method="basic",
            authentication_basic_username="my-username",
            authentication_basic_password="my-password",
            url="https://grafana.com/metrics",
            scrape_interval_seconds=120)
        ```

        ## Import

        ```sh
        $ pulumi import grafana:index/connectionsMetricsEndpointScrapeJob:ConnectionsMetricsEndpointScrapeJob name "{{ stack_id }}:{{ name }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] authentication_basic_password: Password for basic authentication, use if scrape job is using basic authentication method
        :param pulumi.Input[builtins.str] authentication_basic_username: Username for basic authentication, use if scrape job is using basic authentication method
        :param pulumi.Input[builtins.str] authentication_bearer_token: Bearer token used for authentication, use if scrape job is using bearer authentication method
        :param pulumi.Input[builtins.str] authentication_method: Method to pass authentication credentials: basic or bearer.
        :param pulumi.Input[builtins.bool] enabled: Whether the metrics endpoint scrape job is enabled or not.
        :param pulumi.Input[builtins.int] scrape_interval_seconds: Frequency for scraping the metrics endpoint: 30, 60, or 120 seconds.
        :param pulumi.Input[builtins.str] url: The url to scrape metrics from; a valid HTTPs URL is required.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ConnectionsMetricsEndpointScrapeJobArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        test = grafana.connections.MetricsEndpointScrapeJob("test",
            stack_id="1",
            name="my-scrape-job",
            enabled=True,
            authentication_method="basic",
            authentication_basic_username="my-username",
            authentication_basic_password="my-password",
            url="https://grafana.com/metrics",
            scrape_interval_seconds=120)
        ```

        ## Import

        ```sh
        $ pulumi import grafana:index/connectionsMetricsEndpointScrapeJob:ConnectionsMetricsEndpointScrapeJob name "{{ stack_id }}:{{ name }}"
        ```

        :param str resource_name: The name of the resource.
        :param ConnectionsMetricsEndpointScrapeJobArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ConnectionsMetricsEndpointScrapeJobArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 authentication_basic_password: Optional[pulumi.Input[builtins.str]] = None,
                 authentication_basic_username: Optional[pulumi.Input[builtins.str]] = None,
                 authentication_bearer_token: Optional[pulumi.Input[builtins.str]] = None,
                 authentication_method: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 scrape_interval_seconds: Optional[pulumi.Input[builtins.int]] = None,
                 stack_id: Optional[pulumi.Input[builtins.str]] = None,
                 url: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        pulumi.log.warn("""ConnectionsMetricsEndpointScrapeJob is deprecated: grafana.index/connectionsmetricsendpointscrapejob.ConnectionsMetricsEndpointScrapeJob has been deprecated in favor of grafana.connections/metricsendpointscrapejob.MetricsEndpointScrapeJob""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ConnectionsMetricsEndpointScrapeJobArgs.__new__(ConnectionsMetricsEndpointScrapeJobArgs)

            __props__.__dict__["authentication_basic_password"] = None if authentication_basic_password is None else pulumi.Output.secret(authentication_basic_password)
            __props__.__dict__["authentication_basic_username"] = authentication_basic_username
            __props__.__dict__["authentication_bearer_token"] = None if authentication_bearer_token is None else pulumi.Output.secret(authentication_bearer_token)
            if authentication_method is None and not opts.urn:
                raise TypeError("Missing required property 'authentication_method'")
            __props__.__dict__["authentication_method"] = authentication_method
            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["name"] = name
            __props__.__dict__["scrape_interval_seconds"] = scrape_interval_seconds
            if stack_id is None and not opts.urn:
                raise TypeError("Missing required property 'stack_id'")
            __props__.__dict__["stack_id"] = stack_id
            if url is None and not opts.urn:
                raise TypeError("Missing required property 'url'")
            __props__.__dict__["url"] = url
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["authenticationBasicPassword", "authenticationBearerToken"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(ConnectionsMetricsEndpointScrapeJob, __self__).__init__(
            'grafana:index/connectionsMetricsEndpointScrapeJob:ConnectionsMetricsEndpointScrapeJob',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            authentication_basic_password: Optional[pulumi.Input[builtins.str]] = None,
            authentication_basic_username: Optional[pulumi.Input[builtins.str]] = None,
            authentication_bearer_token: Optional[pulumi.Input[builtins.str]] = None,
            authentication_method: Optional[pulumi.Input[builtins.str]] = None,
            enabled: Optional[pulumi.Input[builtins.bool]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            scrape_interval_seconds: Optional[pulumi.Input[builtins.int]] = None,
            stack_id: Optional[pulumi.Input[builtins.str]] = None,
            url: Optional[pulumi.Input[builtins.str]] = None) -> 'ConnectionsMetricsEndpointScrapeJob':
        """
        Get an existing ConnectionsMetricsEndpointScrapeJob resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] authentication_basic_password: Password for basic authentication, use if scrape job is using basic authentication method
        :param pulumi.Input[builtins.str] authentication_basic_username: Username for basic authentication, use if scrape job is using basic authentication method
        :param pulumi.Input[builtins.str] authentication_bearer_token: Bearer token used for authentication, use if scrape job is using bearer authentication method
        :param pulumi.Input[builtins.str] authentication_method: Method to pass authentication credentials: basic or bearer.
        :param pulumi.Input[builtins.bool] enabled: Whether the metrics endpoint scrape job is enabled or not.
        :param pulumi.Input[builtins.int] scrape_interval_seconds: Frequency for scraping the metrics endpoint: 30, 60, or 120 seconds.
        :param pulumi.Input[builtins.str] url: The url to scrape metrics from; a valid HTTPs URL is required.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ConnectionsMetricsEndpointScrapeJobState.__new__(_ConnectionsMetricsEndpointScrapeJobState)

        __props__.__dict__["authentication_basic_password"] = authentication_basic_password
        __props__.__dict__["authentication_basic_username"] = authentication_basic_username
        __props__.__dict__["authentication_bearer_token"] = authentication_bearer_token
        __props__.__dict__["authentication_method"] = authentication_method
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["name"] = name
        __props__.__dict__["scrape_interval_seconds"] = scrape_interval_seconds
        __props__.__dict__["stack_id"] = stack_id
        __props__.__dict__["url"] = url
        return ConnectionsMetricsEndpointScrapeJob(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="authenticationBasicPassword")
    def authentication_basic_password(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Password for basic authentication, use if scrape job is using basic authentication method
        """
        return pulumi.get(self, "authentication_basic_password")

    @property
    @pulumi.getter(name="authenticationBasicUsername")
    def authentication_basic_username(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Username for basic authentication, use if scrape job is using basic authentication method
        """
        return pulumi.get(self, "authentication_basic_username")

    @property
    @pulumi.getter(name="authenticationBearerToken")
    def authentication_bearer_token(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Bearer token used for authentication, use if scrape job is using bearer authentication method
        """
        return pulumi.get(self, "authentication_bearer_token")

    @property
    @pulumi.getter(name="authenticationMethod")
    def authentication_method(self) -> pulumi.Output[builtins.str]:
        """
        Method to pass authentication credentials: basic or bearer.
        """
        return pulumi.get(self, "authentication_method")

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[builtins.bool]:
        """
        Whether the metrics endpoint scrape job is enabled or not.
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="scrapeIntervalSeconds")
    def scrape_interval_seconds(self) -> pulumi.Output[builtins.int]:
        """
        Frequency for scraping the metrics endpoint: 30, 60, or 120 seconds.
        """
        return pulumi.get(self, "scrape_interval_seconds")

    @property
    @pulumi.getter(name="stackId")
    def stack_id(self) -> pulumi.Output[builtins.str]:
        return pulumi.get(self, "stack_id")

    @property
    @pulumi.getter
    def url(self) -> pulumi.Output[builtins.str]:
        """
        The url to scrape metrics from; a valid HTTPs URL is required.
        """
        return pulumi.get(self, "url")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['DashboardArgs', 'Dashboard']

@pulumi.input_type
class DashboardArgs:
    def __init__(__self__, *,
                 config_json: pulumi.Input[builtins.str],
                 folder: Optional[pulumi.Input[builtins.str]] = None,
                 message: Optional[pulumi.Input[builtins.str]] = None,
                 org_id: Optional[pulumi.Input[builtins.str]] = None,
                 overwrite: Optional[pulumi.Input[builtins.bool]] = None):
        """
        The set of arguments for constructing a Dashboard resource.
        :param pulumi.Input[builtins.str] config_json: The complete dashboard model JSON.
        :param pulumi.Input[builtins.str] folder: The id or UID of the folder to save the dashboard in.
        :param pulumi.Input[builtins.str] message: Set a commit message for the version history.
        :param pulumi.Input[builtins.str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[builtins.bool] overwrite: Set to true if you want to overwrite existing dashboard with newer version, same dashboard title in folder or same dashboard uid.
        """
        pulumi.set(__self__, "config_json", config_json)
        if folder is not None:
            pulumi.set(__self__, "folder", folder)
        if message is not None:
            pulumi.set(__self__, "message", message)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if overwrite is not None:
            pulumi.set(__self__, "overwrite", overwrite)

    @property
    @pulumi.getter(name="configJson")
    def config_json(self) -> pulumi.Input[builtins.str]:
        """
        The complete dashboard model JSON.
        """
        return pulumi.get(self, "config_json")

    @config_json.setter
    def config_json(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "config_json", value)

    @property
    @pulumi.getter
    def folder(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id or UID of the folder to save the dashboard in.
        """
        return pulumi.get(self, "folder")

    @folder.setter
    def folder(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "folder", value)

    @property
    @pulumi.getter
    def message(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Set a commit message for the version history.
        """
        return pulumi.get(self, "message")

    @message.setter
    def message(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "message", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter
    def overwrite(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Set to true if you want to overwrite existing dashboard with newer version, same dashboard title in folder or same dashboard uid.
        """
        return pulumi.get(self, "overwrite")

    @overwrite.setter
    def overwrite(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "overwrite", value)


@pulumi.input_type
class _DashboardState:
    def __init__(__self__, *,
                 config_json: Optional[pulumi.Input[builtins.str]] = None,
                 dashboard_id: Optional[pulumi.Input[builtins.int]] = None,
                 folder: Optional[pulumi.Input[builtins.str]] = None,
                 message: Optional[pulumi.Input[builtins.str]] = None,
                 org_id: Optional[pulumi.Input[builtins.str]] = None,
                 overwrite: Optional[pulumi.Input[builtins.bool]] = None,
                 uid: Optional[pulumi.Input[builtins.str]] = None,
                 url: Optional[pulumi.Input[builtins.str]] = None,
                 version: Optional[pulumi.Input[builtins.int]] = None):
        """
        Input properties used for looking up and filtering Dashboard resources.
        :param pulumi.Input[builtins.str] config_json: The complete dashboard model JSON.
        :param pulumi.Input[builtins.int] dashboard_id: The numeric ID of the dashboard computed by Grafana.
        :param pulumi.Input[builtins.str] folder: The id or UID of the folder to save the dashboard in.
        :param pulumi.Input[builtins.str] message: Set a commit message for the version history.
        :param pulumi.Input[builtins.str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[builtins.bool] overwrite: Set to true if you want to overwrite existing dashboard with newer version, same dashboard title in folder or same dashboard uid.
        :param pulumi.Input[builtins.str] uid: The unique identifier of a dashboard. This is used to construct its URL. It's automatically generated if not provided when creating a dashboard. The uid allows having consistent URLs for accessing dashboards and when syncing dashboards between multiple Grafana installs.
        :param pulumi.Input[builtins.str] url: The full URL of the dashboard.
        :param pulumi.Input[builtins.int] version: Whenever you save a version of your dashboard, a copy of that version is saved so that previous versions of your dashboard are not lost.
        """
        if config_json is not None:
            pulumi.set(__self__, "config_json", config_json)
        if dashboard_id is not None:
            pulumi.set(__self__, "dashboard_id", dashboard_id)
        if folder is not None:
            pulumi.set(__self__, "folder", folder)
        if message is not None:
            pulumi.set(__self__, "message", message)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if overwrite is not None:
            pulumi.set(__self__, "overwrite", overwrite)
        if uid is not None:
            pulumi.set(__self__, "uid", uid)
        if url is not None:
            pulumi.set(__self__, "url", url)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter(name="configJson")
    def config_json(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The complete dashboard model JSON.
        """
        return pulumi.get(self, "config_json")

    @config_json.setter
    def config_json(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "config_json", value)

    @property
    @pulumi.getter(name="dashboardId")
    def dashboard_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The numeric ID of the dashboard computed by Grafana.
        """
        return pulumi.get(self, "dashboard_id")

    @dashboard_id.setter
    def dashboard_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "dashboard_id", value)

    @property
    @pulumi.getter
    def folder(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id or UID of the folder to save the dashboard in.
        """
        return pulumi.get(self, "folder")

    @folder.setter
    def folder(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "folder", value)

    @property
    @pulumi.getter
    def message(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Set a commit message for the version history.
        """
        return pulumi.get(self, "message")

    @message.setter
    def message(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "message", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter
    def overwrite(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Set to true if you want to overwrite existing dashboard with newer version, same dashboard title in folder or same dashboard uid.
        """
        return pulumi.get(self, "overwrite")

    @overwrite.setter
    def overwrite(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "overwrite", value)

    @property
    @pulumi.getter
    def uid(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The unique identifier of a dashboard. This is used to construct its URL. It's automatically generated if not provided when creating a dashboard. The uid allows having consistent URLs for accessing dashboards and when syncing dashboards between multiple Grafana installs.
        """
        return pulumi.get(self, "uid")

    @uid.setter
    def uid(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "uid", value)

    @property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The full URL of the dashboard.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "url", value)

    @property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Whenever you save a version of your dashboard, a copy of that version is saved so that previous versions of your dashboard are not lost.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "version", value)


warnings.warn("""grafana.index/dashboard.Dashboard has been deprecated in favor of grafana.oss/dashboard.Dashboard""", DeprecationWarning)


@pulumi.type_token("grafana:index/dashboard:Dashboard")
class Dashboard(pulumi.CustomResource):
    warnings.warn("""grafana.index/dashboard.Dashboard has been deprecated in favor of grafana.oss/dashboard.Dashboard""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 config_json: Optional[pulumi.Input[builtins.str]] = None,
                 folder: Optional[pulumi.Input[builtins.str]] = None,
                 message: Optional[pulumi.Input[builtins.str]] = None,
                 org_id: Optional[pulumi.Input[builtins.str]] = None,
                 overwrite: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        """
        Manages Grafana dashboards.

        * [Official documentation](https://grafana.com/docs/grafana/latest/dashboards/)
        * [HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/dashboard/)

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumiverse_grafana as grafana

        test = grafana.oss.Folder("test",
            title="My Folder",
            uid="my-folder-uid")
        test_dashboard = grafana.oss.Dashboard("test",
            folder=test.uid,
            config_json=json.dumps({
                "title": "My Dashboard",
                "uid": "my-dashboard-uid",
            }))
        ```

        ## Import

        ```sh
        $ pulumi import grafana:index/dashboard:Dashboard name "{{ uid }}"
        ```

        ```sh
        $ pulumi import grafana:index/dashboard:Dashboard name "{{ orgID }}:{{ uid }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] config_json: The complete dashboard model JSON.
        :param pulumi.Input[builtins.str] folder: The id or UID of the folder to save the dashboard in.
        :param pulumi.Input[builtins.str] message: Set a commit message for the version history.
        :param pulumi.Input[builtins.str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[builtins.bool] overwrite: Set to true if you want to overwrite existing dashboard with newer version, same dashboard title in folder or same dashboard uid.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DashboardArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages Grafana dashboards.

        * [Official documentation](https://grafana.com/docs/grafana/latest/dashboards/)
        * [HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/dashboard/)

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumiverse_grafana as grafana

        test = grafana.oss.Folder("test",
            title="My Folder",
            uid="my-folder-uid")
        test_dashboard = grafana.oss.Dashboard("test",
            folder=test.uid,
            config_json=json.dumps({
                "title": "My Dashboard",
                "uid": "my-dashboard-uid",
            }))
        ```

        ## Import

        ```sh
        $ pulumi import grafana:index/dashboard:Dashboard name "{{ uid }}"
        ```

        ```sh
        $ pulumi import grafana:index/dashboard:Dashboard name "{{ orgID }}:{{ uid }}"
        ```

        :param str resource_name: The name of the resource.
        :param DashboardArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DashboardArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 config_json: Optional[pulumi.Input[builtins.str]] = None,
                 folder: Optional[pulumi.Input[builtins.str]] = None,
                 message: Optional[pulumi.Input[builtins.str]] = None,
                 org_id: Optional[pulumi.Input[builtins.str]] = None,
                 overwrite: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        pulumi.log.warn("""Dashboard is deprecated: grafana.index/dashboard.Dashboard has been deprecated in favor of grafana.oss/dashboard.Dashboard""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DashboardArgs.__new__(DashboardArgs)

            if config_json is None and not opts.urn:
                raise TypeError("Missing required property 'config_json'")
            __props__.__dict__["config_json"] = config_json
            __props__.__dict__["folder"] = folder
            __props__.__dict__["message"] = message
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["overwrite"] = overwrite
            __props__.__dict__["dashboard_id"] = None
            __props__.__dict__["uid"] = None
            __props__.__dict__["url"] = None
            __props__.__dict__["version"] = None
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="grafana:index/dashboard:Dashboard")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        super(Dashboard, __self__).__init__(
            'grafana:index/dashboard:Dashboard',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            config_json: Optional[pulumi.Input[builtins.str]] = None,
            dashboard_id: Optional[pulumi.Input[builtins.int]] = None,
            folder: Optional[pulumi.Input[builtins.str]] = None,
            message: Optional[pulumi.Input[builtins.str]] = None,
            org_id: Optional[pulumi.Input[builtins.str]] = None,
            overwrite: Optional[pulumi.Input[builtins.bool]] = None,
            uid: Optional[pulumi.Input[builtins.str]] = None,
            url: Optional[pulumi.Input[builtins.str]] = None,
            version: Optional[pulumi.Input[builtins.int]] = None) -> 'Dashboard':
        """
        Get an existing Dashboard resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] config_json: The complete dashboard model JSON.
        :param pulumi.Input[builtins.int] dashboard_id: The numeric ID of the dashboard computed by Grafana.
        :param pulumi.Input[builtins.str] folder: The id or UID of the folder to save the dashboard in.
        :param pulumi.Input[builtins.str] message: Set a commit message for the version history.
        :param pulumi.Input[builtins.str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[builtins.bool] overwrite: Set to true if you want to overwrite existing dashboard with newer version, same dashboard title in folder or same dashboard uid.
        :param pulumi.Input[builtins.str] uid: The unique identifier of a dashboard. This is used to construct its URL. It's automatically generated if not provided when creating a dashboard. The uid allows having consistent URLs for accessing dashboards and when syncing dashboards between multiple Grafana installs.
        :param pulumi.Input[builtins.str] url: The full URL of the dashboard.
        :param pulumi.Input[builtins.int] version: Whenever you save a version of your dashboard, a copy of that version is saved so that previous versions of your dashboard are not lost.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DashboardState.__new__(_DashboardState)

        __props__.__dict__["config_json"] = config_json
        __props__.__dict__["dashboard_id"] = dashboard_id
        __props__.__dict__["folder"] = folder
        __props__.__dict__["message"] = message
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["overwrite"] = overwrite
        __props__.__dict__["uid"] = uid
        __props__.__dict__["url"] = url
        __props__.__dict__["version"] = version
        return Dashboard(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="configJson")
    def config_json(self) -> pulumi.Output[builtins.str]:
        """
        The complete dashboard model JSON.
        """
        return pulumi.get(self, "config_json")

    @property
    @pulumi.getter(name="dashboardId")
    def dashboard_id(self) -> pulumi.Output[builtins.int]:
        """
        The numeric ID of the dashboard computed by Grafana.
        """
        return pulumi.get(self, "dashboard_id")

    @property
    @pulumi.getter
    def folder(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The id or UID of the folder to save the dashboard in.
        """
        return pulumi.get(self, "folder")

    @property
    @pulumi.getter
    def message(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Set a commit message for the version history.
        """
        return pulumi.get(self, "message")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter
    def overwrite(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Set to true if you want to overwrite existing dashboard with newer version, same dashboard title in folder or same dashboard uid.
        """
        return pulumi.get(self, "overwrite")

    @property
    @pulumi.getter
    def uid(self) -> pulumi.Output[builtins.str]:
        """
        The unique identifier of a dashboard. This is used to construct its URL. It's automatically generated if not provided when creating a dashboard. The uid allows having consistent URLs for accessing dashboards and when syncing dashboards between multiple Grafana installs.
        """
        return pulumi.get(self, "uid")

    @property
    @pulumi.getter
    def url(self) -> pulumi.Output[builtins.str]:
        """
        The full URL of the dashboard.
        """
        return pulumi.get(self, "url")

    @property
    @pulumi.getter
    def version(self) -> pulumi.Output[builtins.int]:
        """
        Whenever you save a version of your dashboard, a copy of that version is saved so that previous versions of your dashboard are not lost.
        """
        return pulumi.get(self, "version")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['AwsAccountArgs', 'AwsAccount']

@pulumi.input_type
class AwsAccountArgs:
    def __init__(__self__, *,
                 regions: pulumi.Input[Sequence[pulumi.Input[builtins.str]]],
                 role_arn: pulumi.Input[builtins.str],
                 stack_id: pulumi.Input[builtins.str],
                 name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a AwsAccount resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] regions: A set of regions that this AWS Account resource applies to.
        :param pulumi.Input[builtins.str] role_arn: An IAM Role ARN string to represent with this AWS Account resource.
        :param pulumi.Input[builtins.str] name: An optional human-readable name for this AWS Account resource.
        """
        pulumi.set(__self__, "regions", regions)
        pulumi.set(__self__, "role_arn", role_arn)
        pulumi.set(__self__, "stack_id", stack_id)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def regions(self) -> pulumi.Input[Sequence[pulumi.Input[builtins.str]]]:
        """
        A set of regions that this AWS Account resource applies to.
        """
        return pulumi.get(self, "regions")

    @regions.setter
    def regions(self, value: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        pulumi.set(self, "regions", value)

    @property
    @pulumi.getter(name="roleArn")
    def role_arn(self) -> pulumi.Input[builtins.str]:
        """
        An IAM Role ARN string to represent with this AWS Account resource.
        """
        return pulumi.get(self, "role_arn")

    @role_arn.setter
    def role_arn(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "role_arn", value)

    @property
    @pulumi.getter(name="stackId")
    def stack_id(self) -> pulumi.Input[builtins.str]:
        return pulumi.get(self, "stack_id")

    @stack_id.setter
    def stack_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "stack_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        An optional human-readable name for this AWS Account resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _AwsAccountState:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 regions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 resource_id: Optional[pulumi.Input[builtins.str]] = None,
                 role_arn: Optional[pulumi.Input[builtins.str]] = None,
                 stack_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering AwsAccount resources.
        :param pulumi.Input[builtins.str] name: An optional human-readable name for this AWS Account resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] regions: A set of regions that this AWS Account resource applies to.
        :param pulumi.Input[builtins.str] resource_id: The ID given by the Grafana Cloud Provider API to this AWS Account resource.
        :param pulumi.Input[builtins.str] role_arn: An IAM Role ARN string to represent with this AWS Account resource.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if regions is not None:
            pulumi.set(__self__, "regions", regions)
        if resource_id is not None:
            pulumi.set(__self__, "resource_id", resource_id)
        if role_arn is not None:
            pulumi.set(__self__, "role_arn", role_arn)
        if stack_id is not None:
            pulumi.set(__self__, "stack_id", stack_id)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        An optional human-readable name for this AWS Account resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def regions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A set of regions that this AWS Account resource applies to.
        """
        return pulumi.get(self, "regions")

    @regions.setter
    def regions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "regions", value)

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID given by the Grafana Cloud Provider API to this AWS Account resource.
        """
        return pulumi.get(self, "resource_id")

    @resource_id.setter
    def resource_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_id", value)

    @property
    @pulumi.getter(name="roleArn")
    def role_arn(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        An IAM Role ARN string to represent with this AWS Account resource.
        """
        return pulumi.get(self, "role_arn")

    @role_arn.setter
    def role_arn(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "role_arn", value)

    @property
    @pulumi.getter(name="stackId")
    def stack_id(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "stack_id")

    @stack_id.setter
    def stack_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "stack_id", value)


@pulumi.type_token("grafana:cloudProvider/awsAccount:AwsAccount")
class AwsAccount(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 regions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 role_arn: Optional[pulumi.Input[builtins.str]] = None,
                 stack_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_aws as aws
        import pulumi_grafana as grafana
        import pulumiverse_grafana as grafana

        test = grafana.cloud.get_stack(slug="gcloudstacktest")
        test_get_role = aws.iam.get_role(name="my-role")
        test_aws_account = grafana.cloud_provider.AwsAccount("test",
            stack_id=test.id,
            role_arn=test_get_role.arn,
            regions=[
                "us-east-1",
                "us-east-2",
                "us-west-1",
            ])
        ```

        ## Import

        ```sh
        $ pulumi import grafana:cloudProvider/awsAccount:AwsAccount name "{{ stack_id }}:{{ resource_id }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] name: An optional human-readable name for this AWS Account resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] regions: A set of regions that this AWS Account resource applies to.
        :param pulumi.Input[builtins.str] role_arn: An IAM Role ARN string to represent with this AWS Account resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AwsAccountArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_aws as aws
        import pulumi_grafana as grafana
        import pulumiverse_grafana as grafana

        test = grafana.cloud.get_stack(slug="gcloudstacktest")
        test_get_role = aws.iam.get_role(name="my-role")
        test_aws_account = grafana.cloud_provider.AwsAccount("test",
            stack_id=test.id,
            role_arn=test_get_role.arn,
            regions=[
                "us-east-1",
                "us-east-2",
                "us-west-1",
            ])
        ```

        ## Import

        ```sh
        $ pulumi import grafana:cloudProvider/awsAccount:AwsAccount name "{{ stack_id }}:{{ resource_id }}"
        ```

        :param str resource_name: The name of the resource.
        :param AwsAccountArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AwsAccountArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 regions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 role_arn: Optional[pulumi.Input[builtins.str]] = None,
                 stack_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AwsAccountArgs.__new__(AwsAccountArgs)

            __props__.__dict__["name"] = name
            if regions is None and not opts.urn:
                raise TypeError("Missing required property 'regions'")
            __props__.__dict__["regions"] = regions
            if role_arn is None and not opts.urn:
                raise TypeError("Missing required property 'role_arn'")
            __props__.__dict__["role_arn"] = role_arn
            if stack_id is None and not opts.urn:
                raise TypeError("Missing required property 'stack_id'")
            __props__.__dict__["stack_id"] = stack_id
            __props__.__dict__["resource_id"] = None
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="grafana:cloud/providerAwsAccount:ProviderAwsAccount")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        super(AwsAccount, __self__).__init__(
            'grafana:cloudProvider/awsAccount:AwsAccount',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            regions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            resource_id: Optional[pulumi.Input[builtins.str]] = None,
            role_arn: Optional[pulumi.Input[builtins.str]] = None,
            stack_id: Optional[pulumi.Input[builtins.str]] = None) -> 'AwsAccount':
        """
        Get an existing AwsAccount resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] name: An optional human-readable name for this AWS Account resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] regions: A set of regions that this AWS Account resource applies to.
        :param pulumi.Input[builtins.str] resource_id: The ID given by the Grafana Cloud Provider API to this AWS Account resource.
        :param pulumi.Input[builtins.str] role_arn: An IAM Role ARN string to represent with this AWS Account resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AwsAccountState.__new__(_AwsAccountState)

        __props__.__dict__["name"] = name
        __props__.__dict__["regions"] = regions
        __props__.__dict__["resource_id"] = resource_id
        __props__.__dict__["role_arn"] = role_arn
        __props__.__dict__["stack_id"] = stack_id
        return AwsAccount(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        An optional human-readable name for this AWS Account resource.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def regions(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        A set of regions that this AWS Account resource applies to.
        """
        return pulumi.get(self, "regions")

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID given by the Grafana Cloud Provider API to this AWS Account resource.
        """
        return pulumi.get(self, "resource_id")

    @property
    @pulumi.getter(name="roleArn")
    def role_arn(self) -> pulumi.Output[builtins.str]:
        """
        An IAM Role ARN string to represent with this AWS Account resource.
        """
        return pulumi.get(self, "role_arn")

    @property
    @pulumi.getter(name="stackId")
    def stack_id(self) -> pulumi.Output[builtins.str]:
        return pulumi.get(self, "stack_id")

